# pltvid

A simple library to capture multiple matplotlib plots as a GIF movie, inspired by the [library](https://github.com/jwkvam/celluloid) from @jwkvam.

This is really meant for my own use, but go for it if you find it helpful.
